@@ -1,19 +1,19 @@
 from .account import Account
 from .account_info import QiwiAccountInfo
 from .balance import Balance
-from .bill import Bill, BillError, RefundBill, Notification, P2PKeys
+from .bill import Bill, BillError, RefundBill, Notification, P2PKeys, InvoiceStatus
 from .commission import Commission
 from .identification import Identification
 from .limit import Limit
 from .other import CrossRate, FreePaymentDetailsFields, PaymentMethod
 from .partner import Partner
-from .payment_info import PaymentInfo
+from .payment_info import PaymentInfo, QiwiPayment
 from .polygon import Polygon
 from .qiwi_master import OrderDetails, Card
 from .restriction import Restriction
 from .stats import Statistic
 from .terminal import Terminal
-from .transaction import Transaction
+from .transaction import Transaction, TransactionType
 from .webhooks import WebHookConfig, WebHook
 
 __all__ = (
@@ -42,4 +42,7 @@ __all__ = (
     "Card",
     "Restriction",
     "Commission",
+    "InvoiceStatus",
+    "TransactionType",
+    "QiwiPayment",
 )
