@@ -1,10 +1,18 @@
+import enum
 from datetime import datetime
 from typing import Optional, Union, Dict, Any, List
 
 from pydantic import Field
 
-from glQiwiApi.types.base import Base
-from glQiwiApi.types.basics import Sum
+from glQiwiApi.types.base import Base, ExtraBase
+from glQiwiApi.types.amount import CurrencyAmount
+
+
+class TransactionType(enum.Enum):
+    IN = "IN"
+    OUT = "OUT"
+    ALL = "ALL"
+    QIWI_CARD = "QIWI_CARD"
 
 
 class Provider(Base):
@@ -32,10 +40,10 @@ class Provider(Base):
     """сайт провайдера"""
 
 
-class Transaction(Base):
+class Transaction(ExtraBase):
     """object: Transaction"""
 
-    transaction_id: int = Field(alias="txnId")
+    id: int = Field(alias="txnId")
     """	ID транзакции в сервисе QIWI Кошелек"""
 
     person_id: int = Field(alias="personId")
@@ -62,7 +70,7 @@ class Transaction(Base):
     ERROR - ошибка платежа.
     """
 
-    type: str
+    type: TransactionType
     """
     Тип платежа. Возможные значения:
     IN - пополнение,
@@ -83,13 +91,13 @@ class Transaction(Base):
     терминала или название агента пополнения кошелька
     """
 
-    sum: Sum
+    sum: CurrencyAmount
     """Данные о сумме платежа или пополнения."""
 
-    commission: Sum
+    commission: CurrencyAmount
     """Данные о комиссии"""
 
-    total: Sum
+    total: CurrencyAmount
     """Общие данные о платеже в формате объекта Sum"""
 
     provider: Provider
@@ -122,10 +130,5 @@ class Transaction(Base):
     _regular_payment_enabled: bool = Field(..., alias="regularPaymentEnabled")
     """Специальное поле"""
 
-    def __str__(self) -> str:
-        return f"""Статус транзакции: {self.status}
-Дата проведения платежа: {self.date}
-Сумма платежа: {self.sum.amount}
-Комментарий: {self.comment if isinstance(self.comment, str) else '-'}
-{"Кому" if self.type == "OUT" else "От кого"}: {self.to_account}
-"""
+    class Config:
+        use_enum_values = True
